(create)(create options)A very simple service that you can use to get rebel readline working without any introspecting functionality (doc, source, appropos, completion, eval).
It's best overide the :prompt option with a fn returns a proper prompt with the current namespace.
A very simple service that you can use to get rebel readline working without any introspecting functionality (doc, source, appropos, completion, eval). It's best overide the :prompt option with a fn returns a proper prompt with the current namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |