(blank-at-position? s pos)(count-leading-white-space s)(delims-outward-from-pos tokens pos)(find-open-sexp-end tokens pos)(find-open-sexp-end tokens pos final-delim-pred)(find-open-sexp-ends tokens pos)(find-open-sexp-start tokens pos)(find-open-sexp-start tokens pos final-delim-pred)(find-open-sexp-starts tokens pos)(first-non-whitespace-char-backwards-from s pos)(funcall-word code-str open-paren-pos)Given a string with sexps an a position into that string that points to an open paren, return the first token that is the function call word
Given a string with sexps an a position into that string that points to an open paren, return the first token that is the function call word
(in-line-comment? tokens pos)(in-non-interp-bounds? code-str pos)(in-quote? tokens pos)(non-interp-bounds code-str)(position-in-range? s pos)(scan-back-from pred s pos)(scan-builder open-test close-test)(search-for-line-start s pos)(sexp-ending-at-position s pos)(sexp-or-word-ending-at-position s pos)(valid-sexp-from-point s pos)(whitespace? c)(word-at-position s pos)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |