returns a read-line prompt string
returns a read-line prompt string
(absolutize-file path-string)Replaces a leading '~' in the path-string with the user's home directory, converts the string to a java.io.File, and normalizes it (collapsing any '/./' or '/../' references).
Replaces a leading '~' in the path-string with the user's home directory, converts the string to a java.io.File, and normalizes it (collapsing any '/./' or '/../' references).
(color sk)(explain-config spec config)(explain-config-header config)(fg-color color)(file-exists? file-path)(highlight-str color-fn tokenizer-fn syntax-str)(highlight-tokens color-fn tokens syntax-str)(not-implemented! service fn-name)(prompt)(register-color-theme! ky color-map)(resolve-fn? f)(service-dispatch a & args)(translate-serialized-key-bindings key-binding-map)(user-config spec overrides)(user-config-file)(valid-config? spec options)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |